==> mediamvp_0.0.9.tar.gz: mediamvp/i18n.c <==
/*
 * i18n.c: Internationalization
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id: i18n.c,v 1.1 2003/12/04 19:41:35 dom Exp $
 */

#include "i18n.h"

const tI18nPhrase Phrases[] = {
    { "Start MediaMVP Server",        // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "MediaMVP GUI Port",            // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "MediaMVP Stream Port",         // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
   { "MediaMVP dongle.bin version",   // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
   { "Total Screen Width",            // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
   { "Total Screen Depth",            // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
   { "GUI Screen Width",              // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
   { "GUI Screen Depth",              // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { NULL }
};

==> mediamvp_0.0.10.tar.gz: mediamvp/i18n.c <==
/*
 * i18n.c: Internationalization
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id: i18n.c,v 1.2 2003/12/11 13:52:03 dom Exp $
 */

#include "i18n.h"

const tI18nPhrase Phrases[] = {
    { "Start MediaMVP Server",        // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "MediaMVP GUI Port",            // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "MediaMVP Stream Port",         // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
   { "MediaMVP dongle.bin version",   // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
   { "Total Screen Width",            // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
   { "Total Screen Depth",            // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
   { "GUI Screen Width",              // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
   { "GUI Screen Depth",              // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "MediaMVP",                     // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "Channels",                     // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "Internet Radio",               // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "Recordings",                     // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "Music",                        // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "Settings",                     // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "NTSC",                         // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "PAL",                          // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "None",                         // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
   { "Low",                           // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
   { "Medium",                        // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "High",                        // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "RGB Detected",                 // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "SVideo",                       // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "Composite",                       // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "RGB/Composite",                // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "TV Mode:",                     // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "Output:",                     // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "Flicker Control:",             // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "Aspect Ratio:",                // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "Cancel changes",               // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { "Save settings (may take a while)",  // English
      "",                             // Deutsch
      "",                             // Slovenski
      "",                             // Italiano
      "",                             // Nederlands
      "",                             // Portugus
      "",                             // Franais
      "",                             // Norsk
      "",                             // Suomi
      "",                             // Polski
      "",                             // Espaol
      "",                             // Ellinika
      "",                             // Svenska
      "",                             // Romaneste
      ""                              // Magyar
    },
    { NULL }
};
